% 1. Respondent number
% 2. Gender (Q1) #
% 3. Age (Q2) #
% 4. Having a driver's license (Q3)
% 5. Years of having a drivers license (Q4) #
% 6. Yearly mileage (Q5) #
% 7. Owning an ACC-equipped car or driving an ACC-equipped car on at least a weekly basis (Q6)
% 8. Car brand (Q7)
% 9. Automatic gearbox (Q8) #
% 10. Full speed range (Q9) # 
% 11. Adjustable headway (Q10)
% 12. Car ownership (Q11)
% 13. Q11: other (free response)
% 14. Car use (Q12)
% 15. Experience with ACC (Q13) #
% 16. Weekly ACC mileage (Q14) #
% 17. Having used ACC in the past 6 months (Q15)
% 18. ACC was a deliberate choice (Q16) #
% 19. Q16: other (free response)
% 20. Informed about ACC (Q17) #
% 21. Aware of limitations/risks of ACC (Q18)
% 22. Q18: other (free response)
% 23. Pleasure: On roads in the built-up area (Q19)
% 24. Pleasure: On provincial roads outside of the built-up area (Q20)
% 25. Pleasure: On expressways (Q21)
% 26. Pleasure: On highways (Q22)
% 27. Space for an optional explanation (*)
% 28. Pleasure: Little to no traffic  No interaction with other vehicles (Q23)
% 29  Pleasure: Average traffic density  Occasional interaction with other vehicles (Q24)
% 30. Pleasure: A lot of traffic  (Almost) continuous interaction with other vehicles (Q25)
% 31. Pleasure: High traffic density  Slowly driving traffic or congestion (Q26)
% 32. Space for an optional explanation (*)
% 33. If I have ACC turned on, driving costs me less effort (Q27)
% 34. If I have ACC turned on, I have to pay less attention in traffic (Q28)
% 35. If I have ACC turned on, I perform more activities while driving (calling, using smartphone, ...) (Q29)
% 36. Space for an optional explanation (*)
% 37. If I have ACC turned on, I have less risk of head-tail collisions (Q30)
% 38. If I have ACC turned on, I less often end up in unsafe situations (Q31)
% 39. If I have ACC turned on, I less often drive faster than the speed limit (Q32)
% 40. If I have ACC turned on, I need more time to brake or apply an additional steering action if needed (Q33)
% 41. I would rather have that ACC only gave a notification and/or auditory signal instead of actively intervening (Q34)
% 42. Space for an optional explanation (*)
% 43. You apply additional throttle in order to reduce a large gap with the vehicle in front because the ACC adopts a too large headway (Q35)
% 44. A car cuts in between you and the vehicle in front, and your car reacts by hard braking (Q36)
% 45. You apply additional throttle to overtake another car, because your car would otherwise brake in response to this car (Q37)
% 46. In a sharp curve the ACC of your car loses sight of the car in front, and so your car accelerates unexpectedly (Q38)
% 47. ACC suddenly disengages while you did not expect this to happen (Q39)
% 48. ACC suddenly brakes or accelerates while you did not expect this to happen (Q40)
% 49. Are there other situations which you experience, or have experienced, while using ACC, and which you consider as unsafe or unpleasant? Please also indicate how often this situation occurs. (*)
% 50. If I have ACC turned on, I drive more uniformly (meaning I have brake or accelerate less often) (Q41)
% 51. If I have ACC turned on, I keep a larger distance to the car in front (Q42)
% 52. If I have ACC turned on, I change lanes on the highway less often (Q43)
% 53. If I have ACC turned on, I drive on the right lane on the highway more often (Q44)
% 54. Space for an optional explanation (*)
% 55. Overall grade (Q45)
% 56. Could you please indicate why you gave this grade? (*)
% 57. Whether they would recommend ACC to another person (Q46)
% 58. Do you have other experiences, remarks, or tips regarding the design and the use of Adaptive Cruise Control? (*)
% 59. Driving style from slow (7) to fast (1) (Q47)
% 60. Driving style from careful (7) to careless (1) (Q48)
% 61. Driving style from tolerant (7) to intolerant (1) (Q49)
% 62. Driving style from indecisive (7) to decisive (1) (Q50)
% 63. How often they drive so close to the car in front that it would be difficult to brake safely in case of an emergency (Q51)
% 64. How often they disobey the speed limit on the highway (Q52)
% 65. How often they receive a fine for a traffic violation (Q53)
% 66. How often they get annoyed with other road users (Q54)
% 67. How often they engage in other activities behind the wheel such as calling, using a smartphone, or smoking (Q55)
% (*) = used in textual analysis
% (#) = used in Figure 1
%%
clear variables;close all force;clc
[X,T]=xlsread('Database.xlsx','A2:BO268');
IT=[2:12 14:18 20:21 23:26 28:31 33:35 37:41 43:48 50:53 55 57 59:67]; % items used in the analysis
X(X>9999)=NaN;
temp=find(X(:,3)>1 & X(:,4)==1 & X(:,7)==1 & X(:,17)==1 & ~isnan(X(:,67))); % at least 18 years, driving license, used ACC in past 6 months, and completed the survey
X=X(temp,:);T=T(temp,:); % select the respondents for inclusion

X(X(:,57)==4,57)=3;X(X(:,57)==6,57)=4;X(X(:,57)==7,57)=5;X(X(:,57)==8,57)=median(X(:,57)); % Q46: transform so that 1 = Strongly disagree, 5 = Strongly agree. Also perform a median replacement for the 2 respondents who answered 'don't know'
X(X(:,10)==2,10)=NaN;X(:,10)=2-X(:,10); % Q9: (0 = full range, 1 = no full range, 3 = don't know) -> (NaN = don't know, 1 = no full range, 2 = full range)
X(X(:,11)==2,11)=NaN; % Q10: If 'don't know' then set to NaN, 0 = no, 1 = yes, it has an adjustable headway
X(X(:,18)==1,18)=0; X(X(:,18)==3,18)=2;X(X(:,18)==2,18)=1; % Q16: (0 = No, 1 = No, other, 2 = Yes, ACC, 3 = Yes, Package) -> (0 = no, 1 = yes)
X(X(:,20)==3,20)=NaN; %  Q17: NaN = don't know
X(:,63:67)=8-X(:,63:67); % Q51-Q55: transform so that 1 = absolutely never, 7 = always

disp('Frequency distribution per item')
disp([ IT' transpose(1:55) sum(isnan(X(:,IT)))' histc(X(:,IT),0:10)'])
%%
x=zscore(tiedrank(X(:,[21 23:26 28:31 33:35 37:41 43:48 50:53 55 57 59:67])));
r=corr(x,'rows','pairwise'); % correlation matrix among 38 items
figure;plot(sort(eig(r),'descend'),'k-o') % make scree plot
xlabel('Eigenvalue nr')
ylabel('Eigenvalue')
[V,D] = svd(r); % singular value decomposition
D = D(1:2,1:2); % eigenvalues
V = V(:,1:2); % eigenvectors
lding = -V * sqrt(D); % the loadings are the eigenvectors multiplied by the square root of the eigenvalues
lding=rotatefactors(lding,'method','varimax');

as=x/lding'; % compute factor scores according to least squares regression (solving scores*lding' = x)
disp('Variance explained (rotation sums of squared loadings')
disp(round(100*mean(lding.^2),1))
disp('Component loadings')
disp([transpose(18:55) round(lding,2)])
%%
SR=tiedrank(as(:,1));
CC=[8 27 32 36 42 49 54 56 58]-7; % textual variables that may provide useful information
for j=1:3
    switch j
        case 1
            temp=find(SR<=20);disp(' ');disp('***** Analysis of responses of respondents who found ACC unpleasant *****')
        case 2
            temp=find(SR>=163);disp(' ');disp('***** Analysis of responses of respondents who found ACC pleasant *****')
        case 3
            temp=find(X(:,11)==0);disp(' ');disp('***** Analysis of responses of respondents who stated that their ACC does not allow for adjusting headway *****')
    end
    for i=1:length(temp)
        id=temp(i);
        disp(' ')
        disp(['Participant satisfaction rank = ' num2str(SR(id))]);
        if X(i,2)==1;disp('Gender = male');else disp('Gender = female');end
        for i2=1:length(CC);
            if ~strcmp(char(T(id,CC(i2))),'9999999');disp(char(T(id,CC(i2))));end
        end
    end
end
%% Analyses by car make
UC=unique(T(:,1));NC=NaN(length(UC),1);NC2=NaN(length(UC),1);NC3=NaN(length(UC),1);CI=NaN(length(UC),2);
for i=1:length(UC);
    NC(i)=sum(strcmp(T(:,1),UC(i))); % number of cars of specific brand
    NC2(i)=sum(strcmp(T(:,1),UC(i)) & X(:,10)==2 );  % number of cars of specific brand & full speed range ACC
    NC3(i)=sum(strcmp(T(:,1),UC(i)) & X(:,10)==2 & X(:,9)==0);  % number of cars of specific brand & full speed range ACC & manual transmission
    disp([char(UC(i)) ', N = ' num2str(NC(i)) ', N full speed range ACC = ' num2str(NC2(i)) ', N full speed range ACC & manual transmission = ' num2str(NC3(i))])
    [~,~,c]=ttest(as(strcmp(T(:,1),UC(i)),1));
    CI(i,:)=c;
end
X(strcmp(T(:,1),'Toyota') & X(:,10)==2,10)=NaN; % Q9: set Toyota with full speed range ACC to NaN
X(strcmp(T(:,1),'Honda') & X(:,10)==2,10)=NaN; % Q9: set Honda with full speed range ACC to NaN
X(X(:,10)==2 & X(:,9)==0,9:10)=NaN; % Q8 & Q9: set manual transmission with full speed range ACC to NaN
X(X(:,11)==0,11)=NaN;
%% Make tables
disp('Table 1');disp(round([squeeze(nanmean(X(:,[23:26 28:31])))' squeeze(nanstd(X(:,[23:26 28:31])))'],2))
disp('Table 2');disp(round([squeeze(nanmean(X(:,[33:35 37:41])))' squeeze(nanstd(X(:,[33:35 37:41])))'],2))
disp('Table 3');disp(round([squeeze(nanmean(X(:,43:48)))' squeeze(nanstd(X(:,43:48)))'],2))
disp('Table 4');disp(round([squeeze(nanmean(X(:,50:53)))' squeeze(nanstd(X(:,50:53)))'],2))
%% Make figure
[c,p]=corr(tiedrank([as, X(:,[2 3 5 6 9 10 15 16 18 20])]),'rows','pairwise');
figure;hold on
barh(c(end:-1:3,1:2))
gc=[.8 .8 .8;0 0 0];colormap(gc);
temp=p(end:-1:3,1:2);
xlabel('Spearman \rho')
set(gca,'Ytick',1:11)
set(gca,'ylim',[.5 10.5])
set(gca,'Yticklabel',{ ['Q17. InformedACC (1' char(8211) '3)'] 'Q16. DeliberateAcc (1=no, 2=yes)' ['Q14. AccKmWeek (1' char(8211) '5)'] ['Q13. AccYears (1' char(8211) '5)'] 'Q9. FullRangeACC (1=no, 2=yes)' 'Q8. AutTrans (1=no, 2=yes)' ['Q5. KmYear (1' char(8211) '5)'] ['Q4. LicenseYears (1' char(8211) '5)'] ['Q2. Age (1' char(8211) '6)'] 'Q1. Gender (1=female, 2=male)'});
legend('ACC pleasantness','Risky driving style','location','northeast','location','NorthOutside','orientation','horizontal')
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Times','Fontsize',20)
for i=1:length(temp)
    for i2=1:2
        p=(temp(i,i2));p=sprintf('%3.3f',p);p=p(2:end);
        if temp(i,i2)<.001;text(0.55,i-0.5+i2*0.35,'\itp\rm < .001','Fontsize',14,'Fontname','Times');else text(0.55,i-0.5+i2*0.35,['\itp\rm = ' p],'Fontsize',14,'Fontname','Times');end
    end
end
set(gcf,'PaperPositionMode','manual','paperunits','inches');
set(gcf,'PaperPosition',[0 0 15 10]);
set(gca,'LooseInset',[0.01 0.01 0.01 0.01]);
print(gcf,'Figure 1','-dpng','-r400','-painters');
%%
disp('Q26. Mean score for full speed range ACC yes vs. no')
disp(round([mean(X(X(:,10)==2,31)) mean(X(X(:,10)==1,31))],2))
disp('Q26. SD score for full speed range ACC yes vs. no')
disp(round([std(X(X(:,10)==2,31)) std(X(X(:,10)==1,31))],2))
[~,p,~,stats]=ttest2(X(X(:,10)==2,31),X(X(:,10)==1,31));
disp('Q26. p, df, and t value for full speed range ACC yes vs. no')
disp([p stats.df stats.tstat])

disp('Q39 Mean score for full speed range ACC yes vs. no')
disp(round([mean(X(X(:,10)==2,47)) mean(X(X(:,10)==1,47))],2))
disp('Q39 SD score for full speed range ACC yes vs. no')
disp(round([std(X(X(:,10)==2,47)) std(X(X(:,10)==1,47))],2))
[~,p,~,stats]=ttest2(X(X(:,10)==2,47),X(X(:,10)==1,47));
disp('Q39. p, df, and t value for full speed range ACC yes vs. no')
disp([p stats.df stats.tstat])